@@ -58,10 +58,12 @@ func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
 			root.getClipboard(ctx)
 		case *eventSearch:
 			searcher := root.setSearcher(ev.str, root.CaseSensitive)
-			root.searchMove(ctx, true, root.Doc.topLN+root.Doc.firstLine()+1, searcher)
+			l := root.lineNumber(root.headerLen + root.Doc.JumpTarget)
+			root.searchMove(ctx, true, l.line+1, searcher)
 		case *eventBackSearch:
 			searcher := root.setSearcher(ev.str, root.CaseSensitive)
-			root.searchMove(ctx, false, root.Doc.topLN+root.Doc.firstLine()-1, searcher)
+			l := root.lineNumber(root.headerLen + root.Doc.JumpTarget)
+			root.searchMove(ctx, false, l.line-1, searcher)
 		case *viewModeInput:
 			root.setViewMode(ev.value)
 		case *searchInput:
@@ -88,6 +90,10 @@ func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
 			root.setSectionDelimiter(ev.value)
 		case *sectionStartInput:
 			root.setSectionStart(ev.value)
+		case *multiColorInput:
+			root.setMultiColor(ev.value)
+		case *jumpTargetInput:
+			root.setJumpTarget(ev.value)
 		case *tcell.EventResize:
 			root.resize()
 		case *tcell.EventMouse:
@@ -279,7 +285,7 @@ type eventSearch struct {
 
 func (root *Root) eventNextSearch() {
 	ev := &eventSearch{}
-	ev.str = root.input.value
+	ev.str = root.searchWord
 	ev.SetEventNow()
 	err := root.Screen.PostEvent(ev)
 	if err != nil {
@@ -295,7 +301,7 @@ type eventBackSearch struct {
 
 func (root *Root) eventNextBackSearch() {
 	ev := &eventBackSearch{}
-	ev.str = root.input.value
+	ev.str = root.searchWord
 	ev.SetEventNow()
 	err := root.Screen.PostEvent(ev)
 	if err != nil {
