@@ -86,6 +86,7 @@ func KeyBindString(k KeyBind) string {
 	k.writeKeyBind(&b, actionColumnMode, "column mode toggle")
 	k.writeKeyBind(&b, actionAlternate, "alternate rows of style toggle")
 	k.writeKeyBind(&b, actionLineNumMode, "line number toggle")
+	k.writeKeyBind(&b, actionPlain, "original decoration toggle")
 
 	fmt.Fprint(&b, gchalk.Bold("\n\tChange Display with Input\n"))
 	fmt.Fprint(&b, "\n")
@@ -94,6 +95,8 @@ func KeyBindString(k KeyBind) string {
 	k.writeKeyBind(&b, actionHeader, "number of header lines")
 	k.writeKeyBind(&b, actionSkipLines, "number of skip lines")
 	k.writeKeyBind(&b, actionTabWidth, "TAB width")
+	k.writeKeyBind(&b, actionMultiColor, "multi color highlight")
+	k.writeKeyBind(&b, actionJumpTarget, "jump target")
 
 	fmt.Fprint(&b, gchalk.Bold("\n\tSection\n"))
 	fmt.Fprint(&b, "\n")
