@@ -27,6 +27,8 @@ type Input struct {
 	WriteBACandidate      *candidate
 	SectionDelmCandidate  *candidate
 	SectionStartCandidate *candidate
+	MultiColorCandidate   *candidate
+	JumpTargetCandidate   *candidate
 }
 
 // InputMode represents the state of the input.
@@ -59,6 +61,10 @@ const (
 	SectionDelimiter
 	// SectionStart is a section start position input mode.
 	SectionStart
+	// MultiColor is multi-word coloring.
+	MultiColor
+	// JumpTarget is the position to display the search results.
+	JumpTarget
 )
 
 // InputEvent input key events.
@@ -287,6 +293,15 @@ func NewInput() *Input {
 			"0",
 		},
 	}
+	i.MultiColorCandidate = &candidate{
+		list: []string{
+			"error info warn debug",
+			"ERROR WARNING NOTICE INFO PANIC FATAL LOG",
+		},
+	}
+	i.JumpTargetCandidate = &candidate{
+		list: []string{},
+	}
 	i.EventInput = &normalInput{}
 	return &i
 }
@@ -389,6 +404,22 @@ func (root *Root) setSectionStartMode() {
 	input.EventInput = newSectionStartInput(input.SectionStartCandidate)
 }
 
+func (root *Root) setMultiColorMode() {
+	input := root.input
+	input.value = ""
+	input.cursorX = 0
+	input.mode = MultiColor
+	input.EventInput = newMultiColorInput(input.MultiColorCandidate)
+}
+
+func (root *Root) setJumpTargetMode() {
+	input := root.input
+	input.value = ""
+	input.cursorX = 0
+	input.mode = JumpTarget
+	input.EventInput = newJumpTargetInput(input.JumpTargetCandidate)
+}
+
 // EventInput is a generic interface for inputs.
 type EventInput interface {
 	// Prompt returns the prompt string in the input field.
@@ -524,10 +555,8 @@ func (g *gotoInput) Prompt() string {
 // Confirm returns the event when the input is confirmed.
 func (g *gotoInput) Confirm(str string) tcell.Event {
 	g.value = str
-	if _, err := strconv.Atoi(str); err == nil {
-		g.clist.list = toLast(g.clist.list, str)
-		g.clist.p = 0
-	}
+	g.clist.list = toLast(g.clist.list, str)
+	g.clist.p = 0
 	g.SetEventNow()
 	return g
 }
@@ -901,12 +930,73 @@ func (d *sectionStartInput) Down(str string) string {
 	return d.clist.down()
 }
 
-func toLast(list []string, s string) []string {
-	if len(s) == 0 {
-		return list
-	}
-
-	list = remove(list, s)
-	list = append(list, s)
-	return list
+// multiColorInput represents the multi color input mode.
+type multiColorInput struct {
+	value string
+	clist *candidate
+	tcell.EventTime
+}
+
+func newMultiColorInput(clist *candidate) *multiColorInput {
+	return &multiColorInput{clist: clist}
+}
+
+// Prompt returns the prompt string in the input field.
+func (d *multiColorInput) Prompt() string {
+	return "multicolor:"
+}
+
+// Confirm returns the event when the input is confirmed.
+func (d *multiColorInput) Confirm(str string) tcell.Event {
+	d.value = str
+	d.clist.list = toLast(d.clist.list, str)
+	d.clist.p = 0
+	d.SetEventNow()
+	return d
+}
+
+// Up returns strings when the up key is pressed during input.
+func (d *multiColorInput) Up(str string) string {
+	return d.clist.up()
+}
+
+// Down returns strings when the down key is pressed during input.
+func (d *multiColorInput) Down(str string) string {
+	return d.clist.down()
+}
+
+// jumpTargetInput represents the jump target input mode.
+type jumpTargetInput struct {
+	value string
+	clist *candidate
+	tcell.EventTime
+}
+
+// newJumpTargetInput returns JumpTargetInput.
+func newJumpTargetInput(clist *candidate) *jumpTargetInput {
+	return &jumpTargetInput{clist: clist}
+}
+
+// Prompt returns the prompt string in the input field.
+func (j *jumpTargetInput) Prompt() string {
+	return "Jump Target line:"
+}
+
+// Confirm returns the event when the input is confirmed.
+func (j *jumpTargetInput) Confirm(str string) tcell.Event {
+	j.value = str
+	j.clist.list = toLast(j.clist.list, str)
+	j.clist.p = 0
+	j.SetEventNow()
+	return j
+}
+
+// Up returns strings when the up key is pressed during input.
+func (g *jumpTargetInput) Up(str string) string {
+	return g.clist.up()
+}
+
+// Down returns strings when the down key is pressed during input.
+func (g *jumpTargetInput) Down(str string) string {
+	return g.clist.down()
 }
