@@ -18,6 +18,7 @@ const (
 	actionFollow         = "follow_mode"
 	actionFollowAll      = "follow_all"
 	actionFollowSection  = "follow_section"
+	actionPlain          = "plain_mode"
 	actionCloseFile      = "close_file"
 	actionReload         = "reload"
 	actionWatch          = "watch"
@@ -64,6 +65,8 @@ const (
 	actionPreviousDoc    = "previous_doc"
 	actionCloseDoc       = "close_doc"
 	actionToggleMouse    = "toggle_mouse"
+	actionMultiColor     = "multi_color"
+	actionJumpTarget     = "jump_target"
 
 	inputCaseSensitive = "input_casesensitive"
 	inputIncSearch     = "input_incsearch"
@@ -81,6 +84,7 @@ func (root *Root) setHandler() map[string]func() {
 		actionFollow:         root.toggleFollowMode,
 		actionFollowAll:      root.toggleFollowAll,
 		actionFollowSection:  root.toggleFollowSection,
+		actionPlain:          root.togglePlain,
 		actionReload:         root.Reload,
 		actionWatch:          root.toggleWatch,
 		actionWatchInterval:  root.setWatchIntervalMode,
@@ -127,9 +131,12 @@ func (root *Root) setHandler() map[string]func() {
 		actionPreviousDoc:    root.previousDoc,
 		actionCloseDoc:       root.closeDocument,
 		actionToggleMouse:    root.toggleMouse,
-		inputCaseSensitive:   root.inputCaseSensitive,
-		inputIncSearch:       root.inputIncSearch,
-		inputRegexpSearch:    root.inputRegexpSearch,
+		actionMultiColor:     root.setMultiColorMode,
+		actionJumpTarget:     root.setJumpTargetMode,
+
+		inputCaseSensitive: root.inputCaseSensitive,
+		inputIncSearch:     root.inputIncSearch,
+		inputRegexpSearch:  root.inputRegexpSearch,
 	}
 }
 
@@ -146,6 +153,7 @@ func defaultKeyBinds() map[string][]string {
 		actionFollow:         {"ctrl+f"},
 		actionFollowAll:      {"ctrl+a"},
 		actionFollowSection:  {"F2"},
+		actionPlain:          {"ctrl+e"},
 		actionCloseFile:      {"ctrl+F9", "ctrl+alt+s"},
 		actionReload:         {"F5", "ctrl+alt+l"},
 		actionWatch:          {"F4", "ctrl+alt+w"},
@@ -193,6 +201,8 @@ func defaultKeyBinds() map[string][]string {
 		actionCloseDoc:       {"ctrl+k"},
 		actionToggleMouse:    {"ctrl+alt+r"},
 		actionSuspend:        {"ctrl+z"},
+		actionMultiColor:     {"."},
+		actionJumpTarget:     {"j"},
 
 		inputCaseSensitive: {"alt+c"},
 		inputIncSearch:     {"alt+i"},
