@@ -133,6 +133,8 @@ type general struct {
 	FollowAll bool
 	// FollowSection is a follow mode that uses section instead of line.
 	FollowSection bool
+	// PlainMode is whether to enable the original character decoration.
+	PlainMode bool
 	// WatchInterval is the watch interval (seconds).
 	WatchInterval int
 	// MarkStyleWidth is width to apply the style of the marked line.
@@ -143,6 +145,10 @@ type general struct {
 	SectionDelimiterReg *regexp.Regexp
 	// SectionStartPosition is a section start position.
 	SectionStartPosition int
+	// Specified string for jumpTarget.
+	JumpTargetString string
+	// JumpTarget is the display position of search results.
+	JumpTarget int
 }
 
 // Config represents the settings of ov.
@@ -167,6 +173,10 @@ type Config struct {
 	StyleMarkLine OVStyle
 	// StyleSectionLine is a style that section delimiter line.
 	StyleSectionLine OVStyle
+	// StyleMultiColorHighlight is the style that applies to the multi color highlight.
+	StyleMultiColorHighlight []OVStyle
+	// StyleJumpTargetLine is the line that displays the search results.
+	StyleJumpTargetLine OVStyle
 
 	// General represents the general behavior.
 	General general
@@ -360,10 +370,23 @@ func NewConfig() Config {
 		StyleSectionLine: OVStyle{
 			Background: "green",
 		},
+		StyleMultiColorHighlight: []OVStyle{
+			{Foreground: "red"},
+			{Foreground: "aqua"},
+			{Foreground: "yellow"},
+			{Foreground: "fuchsia"},
+			{Foreground: "lime"},
+			{Foreground: "blue"},
+			{Foreground: "grey"},
+		},
+		StyleJumpTargetLine: OVStyle{
+			Underline: true,
+		},
 		General: general{
 			TabWidth:             8,
 			MarkStyleWidth:       1,
 			SectionStartPosition: 0,
+			JumpTarget:           0,
 		},
 	}
 }
@@ -780,3 +803,10 @@ func (root *Root) WriteLog() {
 	end := m.BufEndNum()
 	m.Export(os.Stdout, start, end)
 }
+
+func (root *Root) lineNumber(y int) lineNumber {
+	if y >= 0 && y <= len(root.lnumber) {
+		return root.lnumber[y]
+	}
+	return root.lnumber[0]
+}
